%     This file is part of correlation_gui.
% 
%     correlation_gui is free software: you can redistribute it and/or modify
%     it under the terms of the GNU General Public License as published by
%     the Free Software Foundation, either version 3 of the License, or
%     any later version.
% 
%     correlation_gui is distributed in the hope that it will be useful,
%     but WITHOUT ANY WARRANTY; without even the implied warranty of
%     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%     GNU General Public License for more details.
% 
%     You should have received a copy of the GNU General Public License
%     along with correlation_gui.  If not, see <http://www.gnu.org/licenses/>.
% 
%     Diese Datei ist Teil von correlation_gui.
% 
%     correlation_gui ist Freie Software: Sie knnen es unter den Bedingungen
%     der GNU General Public License, wie von der Free Software Foundation,
%     Version 3 der Lizenz oder jeder neueren verffentlichten Version, 
%     weiter verteilen und/oder modifizieren.
% 
%     correlation_gui wird in der Hoffnung, dass es ntzlich sein wird, aber
%     OHNE JEDE GEWHRLEISTUNG, bereitgestellt; sogar ohne die implizite
%     Gewhrleistung der MARKTFHIGKEIT oder EIGNUNG FR EINEN BESTIMMTEN ZWECK.
%     Siehe die GNU General Public License fr weitere Details.
% 
%     Sie sollten eine Kopie der GNU General Public License zusammen mit diesem
%     Programm erhalten haben. Wenn nicht, siehe <https://www.gnu.org/licenses/>.

function handles = deleteResults(handles, level)
% deleteResults -   Deletes all calculated results starting from the level
%                   specified in 'level'
% 
% Syntax:  handles = deleteResults(handles, level)
%
% Inputs:
%    handles - handles structure with all data from the main GUI
%    level - specifies the programm level after which all calculated
%               results shall be deleted; 
%            possible levels are: 
%               'data' - when new data is loaded; all results need to be
%               deleted
%               'PorodFit' - inputs for PorodFit are changed; PorodFit
%               results and everything later needs to be deleted
%               'ModelFcn' - inputs for the model function fit are changed
%
% Outputs:
%   handles - handles structure with all remaining data for the main GUI

% Other m-files required: none
% Subfunctions: none
% MAT-files required: none
%
% Variables: 	
%
% Known bugs: none
%
% Author: Susanne Pieschner
% Last revision: 8-July-2015

%%
switch level
    case 'data'
        cla(handles.axes1) % deletes plot
        pause off; brush off;
        
        set(handles.text_dataFileName, 'String', 'No data loaded');
        
        set(handles.pb_plot_absInt,'Enable','off');
        
        set(handles.edit_beamStop,'String',num2str(0));
        set(handles.text_numDataPoints,'String',num2str(0));
        set(handles.text_totalNumOfDataPoints,'String',num2str(0));
        
        set(handles.text_minScattVectPorodFit,'String','-');
        set(handles.text_maxScattVectPorodFit,'String','-');
        set(handles.edit_minIndexPorodFitRange,'String','-');
        set(handles.edit_maxIndexPorodFitRange,'String','-');
        set(handles.edit_minIndexPorodFitRange,'Enable','off');
        set(handles.edit_maxIndexPorodFitRange,'Enable','off');
        set(handles.edit_startValueP1,'Enable','off');
        set(handles.edit_startValueP2,'Enable','off');
        set(handles.edit_startValueP3,'Enable','off');
        set(handles.edit_startValueP4,'Enable','off');
        set(handles.edit_fixedValueP,'Enable','off');
        set(handles.edit_fixedValueC1,'Enable','off');
        set(handles.edit_fixedValueC2,'Enable','off');
        set(handles.cb_fixP,'Enable','off');
        set(handles.cb_fixC1,'Enable','off');
        set(handles.cb_fixC2,'Enable','off');
        set(handles.pb_calcPorodFit,'Enable','off');
        set(handles.edit_widthOfWindowFcn,'Enable','off');
        
        if( isfield(handles,'Is2') )
            handles = rmfield(handles,{'Is2'}); 
        end
        
        if( isfield(handles,'K') )
            handles = rmfield(handles,{'K', 'zValues'}); 
        end
        
        if( isfield(handles,'porodFit') )
            handles = rmfield(handles,{'porodFit', 'porodFitP', 'porodFitC1', ...
            'porodFitC2', 'K2Zero', 'porodFitErrorNorm'}); 
            set(handles.pb_plot_addFit,'Enable','off');
            set(handles.pb_plot_Is2,'Enable','off');
            set(handles.pb_plot_K,'Enable','off');
            set(handles.pb_plot_PIs4,'Enable','off');
            set(handles.pb_plot_K2,'Enable','off');
            set(handles.text_resultsPorodFit,'String','');
        end
        
        if( isfield(handles,'PIs4') )
            handles = rmfield(handles,{'PIs4', 'equidistScattVect'});
            set(handles.pb_fitModelFcn,'Enable','off');
            set(handles.edit_startValSigmaA,'Enable','off');
            set(handles.edit_startValSigmaC,'Enable','off');
            set(handles.edit_startValDA,'Enable','off');
            set(handles.edit_startValDC,'Enable','off');
            set(handles.edit_lowBoundSigmaA,'Enable','off');
            set(handles.edit_lowBoundSigmaC,'Enable','off');
            set(handles.edit_lowBoundDA,'Enable','off');
            set(handles.edit_lowBoundDC,'Enable','off');
            set(handles.edit_upBoundSigmaA,'Enable','off');
            set(handles.edit_upBoundSigmaC,'Enable','off');
            set(handles.edit_upBoundDA,'Enable','off');
            set(handles.edit_upBoundDC,'Enable','off');
            set(handles.edit_stepSize,'Enable','off');
            set(handles.edit_resolWidth,'Enable','off');
        end
        
        if( isfield(handles,'K2') )
            handles = rmfield(handles,{'K2'}); 
        end

        if( isfield(handles,'modelFcnFit') )
            handles = rmfield(handles,{'modelFcnFit', 'paramModelFcnFit',...
             'PIs4HighResol', 'scattVectHighResol'});             
            set(handles.pb_addModelFcnFit,'Enable','off');
            set(handles.pb_addFFTModelFit,'Enable','off');
            set(handles.text_resultsModelFcnFit,'String','');
        end

        if( isfield(handles,'transformedModelFcn') )
            handles = rmfield(handles,{'transformedModelFcn',...
            'zValTransformedModelFcn' }); 
        end
        
        set(handles.menu_saveAll,'Enable','off');
        
    case 'PorodFit'
        pause off; brush off;
        if( isfield(handles,'porodFit') )
            handles = rmfield(handles,{'porodFit', 'porodFitP', 'porodFitC1', ...
            'porodFitC2', 'K2Zero', 'porodFitErrorNorm'}); 
            set(handles.pb_plot_addFit,'Enable','off');
            set(handles.pb_plot_Is2,'Enable','off');
            set(handles.pb_plot_K,'Enable','off');
            set(handles.pb_plot_PIs4,'Enable','off');
            set(handles.pb_plot_K2,'Enable','off');
            set(handles.text_resultsPorodFit,'String','');
        end
        
        if( isfield(handles,'Is2') )
            handles = rmfield(handles,{'Is2'}); 
        end
        
        if( isfield(handles,'K') )
            handles = rmfield(handles,{'K', 'zValues'}); 
        end
        
        if( isfield(handles,'PIs4') )
            handles = rmfield(handles,{'PIs4', 'equidistScattVect'});
            set(handles.pb_fitModelFcn,'Enable','off');
            set(handles.edit_startValSigmaA,'Enable','off');
            set(handles.edit_startValSigmaC,'Enable','off');
            set(handles.edit_startValDA,'Enable','off');
            set(handles.edit_startValDC,'Enable','off');
            set(handles.edit_lowBoundSigmaA,'Enable','off');
            set(handles.edit_lowBoundSigmaC,'Enable','off');
            set(handles.edit_lowBoundDA,'Enable','off');
            set(handles.edit_lowBoundDC,'Enable','off');
            set(handles.edit_upBoundSigmaA,'Enable','off');
            set(handles.edit_upBoundSigmaC,'Enable','off');
            set(handles.edit_upBoundDA,'Enable','off');
            set(handles.edit_upBoundDC,'Enable','off');
            set(handles.edit_stepSize,'Enable','off');
            set(handles.edit_resolWidth,'Enable','off');
        end
        
        if( isfield(handles,'K2') )
            handles = rmfield(handles,{'K2'}); 
        end

        if( isfield(handles,'modelFcnFit') )
            handles = rmfield(handles,{'modelFcnFit', 'paramModelFcnFit',...
            'PIs4HighResol', 'scattVectHighResol'});             
            set(handles.pb_addModelFcnFit,'Enable','off');
            set(handles.pb_addFFTModelFit,'Enable','off');
            set(handles.text_resultsModelFcnFit,'String','');
        end

        if( isfield(handles,'transformedModelFcn') )
            handles = rmfield(handles,{'transformedModelFcn',...
            'zValTransformedModelFcn' }); 
        end
        
        set(handles.menu_saveAll,'Enable','off');
        
    case 'ModelFcn'
        pause off; brush off;
        if( isfield(handles,'modelFcnFit') )
            handles = rmfield(handles,{'modelFcnFit', 'paramModelFcnFit',...
            'PIs4HighResol', 'scattVectHighResol'}); 
            set(handles.pb_addModelFcnFit,'Enable','off');
            set(handles.pb_addFFTModelFit,'Enable','off');
            set(handles.text_resultsModelFcnFit,'String','');
        end

        if( isfield(handles,'transformedModelFcn') )
            handles = rmfield(handles,{'transformedModelFcn',...
            'zValTransformedModelFcn' }); 
        end
        
        set(handles.menu_saveAll,'Enable','off');

end