%     This file is part of correlation_gui.
% 
%     correlation_gui is free software: you can redistribute it and/or modify
%     it under the terms of the GNU General Public License as published by
%     the Free Software Foundation, either version 3 of the License, or
%     any later version.
% 
%     correlation_gui is distributed in the hope that it will be useful,
%     but WITHOUT ANY WARRANTY; without even the implied warranty of
%     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%     GNU General Public License for more details.
% 
%     You should have received a copy of the GNU General Public License
%     along with correlation_gui.  If not, see <http://www.gnu.org/licenses/>.
% 
%     Diese Datei ist Teil von correlation_gui.
% 
%     correlation_gui ist Freie Software: Sie knnen es unter den Bedingungen
%     der GNU General Public License, wie von der Free Software Foundation,
%     Version 3 der Lizenz oder jeder neueren verffentlichten Version, 
%     weiter verteilen und/oder modifizieren.
% 
%     correlation_gui wird in der Hoffnung, dass es ntzlich sein wird, aber
%     OHNE JEDE GEWHRLEISTUNG, bereitgestellt; sogar ohne die implizite
%     Gewhrleistung der MARKTFHIGKEIT oder EIGNUNG FR EINEN BESTIMMTEN ZWECK.
%     Siehe die GNU General Public License fr weitere Details.
% 
%     Sie sollten eine Kopie der GNU General Public License zusammen mit diesem
%     Programm erhalten haben. Wenn nicht, siehe <https://www.gnu.org/licenses/>.

function saveAvailableResults(handles)
% saveAll -     Saves all data, parameters and calculated results to the
%               file specified by handles.filePathSave and
%               handles.fileNameSave
% 
% Syntax:  saveAll(handles)
%
% Inputs:
%    handles - handles structure with all data from the main GUI
%
% Outputs:
%

% Other m-files required: none
% Subfunctions: none
% MAT-files required: none
%
% Variables: 	
%
% Known bugs: none
%
% Author: Susanne Pieschner
% Last revision: 8-July-2015

%%

% open/create result file for writing. Discard existing contents, if any
resultFile =  fopen([handles.pathNameSave handles.fileNameSave],'w');

fprintf(resultFile,'%-20s %20s\n','# Calculation date: ', datestr(now));
fprintf(resultFile,'%-c\n','#' );

%% input data
fprintf(resultFile,'%-20s\n','# [Input data]');
fprintf(resultFile,'%-20s\n',['# File = ' handles.fileName]);
fprintf(resultFile,'%-20s %3.0f %7s\n','# Beam stop cut-off:',...
   handles.indexBeamStop, 'data points');
fprintf(resultFile,'%-20s %6.0f\n','# Number of data points used:',...
   handles.numDataUsed);
fprintf(resultFile,'%-c\n','#');

%% Porod fit
fprintf(resultFile,'%-20s\n','# [PorodFit]');
fprintf(resultFile,'%-20s %10.8f %c %10.8f\n',...
    '# Porod fitting range, s [1/nm]: ', handles.minScattVectPorod,...
    '-' ,handles.maxScattVectPorod);
fprintf(resultFile,'%-30s\n',...
    '# Fitting function: I(s) = P*s^(-4) + c1*s^2 + c2');
fprintf(resultFile,'%-30s\n',...
    '# Fitted parameters:');

isFixedText = {''; '   fixed'};
fprintf(resultFile,'%-5s %14.8f %8s\n', '#  P  = ', handles.porodFitP,...
        isFixedText{handles.isFixedP+1});
fprintf(resultFile,'%-5s %14.8f %8s\n', '#  c1 = ', handles.porodFitC1,...
    isFixedText{handles.isFixedC1+1});
fprintf(resultFile,'%-5s %14.8f %8s\n', '#  c2 = ', handles.porodFitC2,... 
        isFixedText{handles.isFixedC2+1});
fprintf(resultFile,'%-5s %12.8g\n', '#  K''''(0) = ',handles.K2Zero);
fprintf(resultFile,'%-5s %12.8g\n', '#  Error norm: || I - I_fit ||_2 = ',...
        handles.porodFitErrorNorm);
fprintf(resultFile,'%-c\n','#');

fprintf(resultFile,'%-20s\n','# [DCT]');
fprintf(resultFile,'%-20s %10.5f\n',...
    '# Width of Gaussian window function: ', handles.sigma);
fprintf(resultFile,'%-c\n','#');

%% model function fit
fprintf(resultFile,'%-20s\n','# [Model function fit]');
fprintf(resultFile,'%-20s\n','# Parameter inputs:');    

fprintf(resultFile,'%-13s %13s %12s %12s\n','#', 'starting value', ...
    'lower bound', 'upper bound');
A = [handles.startValModelFcnFit' handles.lowBoundModelFcnFit'...
    handles.upBoundModelFcnFit'];
fprintf(resultFile,'%-13s %13f %12f %12f\n','# sigma_a',A(1,:));
fprintf(resultFile,'%-13s %13f %12f %12f\n','# sigma_c',A(2,:));
fprintf(resultFile,'%-13s %13f %12f %12f\n','# d_a',A(3,:));
fprintf(resultFile,'%-13s %13f %12f %12f\n','# d_c',A(4,:));
fprintf(resultFile,'%-c\n','#');
fprintf(resultFile,'%-15s %10.8f\n', ['# Step size for higher '...
    'resolution of the model function[1/nm]: '], ...
    handles.stepSizeModelFcnFit);
fprintf(resultFile,'%-15s %10.8f\n', ['# Resolution width for '...
    'convultion in model function [1/nm]: '], handles.resolWidthModelFcnFit);

fprintf(resultFile,'%-30s\n',...
    '# Fitted parameters:');
fprintf(resultFile,'%-5s %14.8f \n', '#  Sigma_a = ',...
    handles.paramModelFcnFit(1));
fprintf(resultFile,'%-5s %14.8f \n', '#  Sigma_c = ',...
    handles.paramModelFcnFit(2));
fprintf(resultFile,'%-5s %14.8f \n', '#  d_a     = ',...
    handles.paramModelFcnFit(3));
fprintf(resultFile,'%-5s %14.8f \n', '#  d_c     = ',...
    handles.paramModelFcnFit(4));
fprintf(resultFile,'%-5s %14.8g \n', '#  Error norm = ',...
    handles.errorNormModelFcnFit);
fprintf(resultFile,'%-c\n','#');
fprintf(resultFile,'%-c\n','#');

%% data and results
fprintf(resultFile,'%-20s\n','# [Results]');

%% first table
% columns: scatter vectors, absolute intensities, desmeared errors, Is2, Porod Fit
if (isempty(handles.desmearedError))
    Results1 = [handles.scattVect(handles.indexBeamStop+1:end) ...
       handles.absInt(handles.indexBeamStop+1:end) ...
       handles.Is2 handles.porodFit];
    fprintf(resultFile,'%-3s %15s %15s  %15s %20s \n', '#  ','scatter vectors',...
        'abs. intensity', 'I(s)*s^2', 'P*s^(-4)+c1*s^2+c2');
    fprintf(resultFile,'%-3s %15s %15s %15s %20s \n', '#  ',' in [1/nm]',...
        ' in [e.u./nm^3]', ' in [e.u./nm^5]', ' in [e.u./nm^3]');
    % Note: transpose of results matrix is used to write the file 
    fprintf(resultFile,' %18.10f %15.3f  %15.8f %20.8f\n', Results1');
else
    Results1 = [handles.scattVect(handles.indexBeamStop+1:end) ...
       handles.absInt(handles.indexBeamStop+1:end) ...
       handles.desmearedError(handles.indexBeamStop+1:end)...
       handles.Is2(handles.indexBeamStop+1:end) handles.porodFit];
    fprintf(resultFile,'%-3s %15s %15s %11s %15s %20s \n', '#  ','scatter vectors',...
        'abs. intensity', 'Error', 'I(s)*s^2', 'P*s^(-4)+c1*s^2+c2');
    fprintf(resultFile,'%-3s %15s %15s %11s %15s %20s \n', '#  ',' in [1/nm]',...
        ' in [e.u./nm^3]',' ',  ' in [e.u./nm^5]', ' in [e.u./nm^3]');
    % Note: transpose of results matrix is used to write the file 
    fprintf(resultFile,' %18.10f %15.3f %11.3f %15.8f %20.8f\n', Results1');
end


%% second table
% columns: equidistant scatter vectors, PIs4, model function fit
Results2 = [handles.equidistScattVect handles.PIs4...
            interp1(handles.scattVectHighResol,handles.modelFcnFit,...
                    handles.equidistScattVect)];
fprintf(resultFile,'\n%-3s %15s %25s %20s \n', '#  ','equidistant',...
    '16*pi^3*wf(s)*', 'model function');
fprintf(resultFile,'%-3s %15s %25s %20s  \n', '#  ','scatter vectors',...
    '(P-(I-c2)*s^4+c1*s^6)',' ');
fprintf(resultFile,'%-3s %15s %25s %20s \n', '#  ',' in [1/nm]',...
    ' in [e.u./nm^7]', ' in [e.u./nm^7]');
% Note: transpose of results matrix is used to write the file 
fprintf(resultFile,' %18.10f %25.10f %20.10f \n', Results2');


%% third table
% columns: zvalues, K''(z), transformed model function, K(z)
Results3 = [handles.zValues handles.K2...
        interp1(handles.zValTransformedModelFcn,handles.transformedModelFcn,...
                    handles.zValues) handles.K ];
fprintf(resultFile,'\n%-3s %15s %15s %15s %15s \n', '#  ','z',...
    'K''''(z)','transformed', 'K(z)');
fprintf(resultFile,'%-3s %15s %15s %15s %15s \n', '#  ', '',...
    '','model function','');
fprintf(resultFile,'%-3s %15s %15s %15s %15s \n', '#  ',' in [nm]',...
    ' in [1/nm^8]',' in [1/nm^8]', ' in [1/nm^6]');
% Note: transpose of results matrix is used to write the file 
fprintf(resultFile,' %18.8f %15.8f %15.8f %15.8f\n', Results3');

%% close file
fclose(resultFile);