%     This file is part of correlation_gui.
% 
%     correlation_gui is free software: you can redistribute it and/or modify
%     it under the terms of the GNU General Public License as published by
%     the Free Software Foundation, either version 3 of the License, or
%     any later version.
% 
%     correlation_gui is distributed in the hope that it will be useful,
%     but WITHOUT ANY WARRANTY; without even the implied warranty of
%     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%     GNU General Public License for more details.
% 
%     You should have received a copy of the GNU General Public License
%     along with correlation_gui.  If not, see <http://www.gnu.org/licenses/>.
% 
%     Diese Datei ist Teil von correlation_gui.
% 
%     correlation_gui ist Freie Software: Sie knnen es unter den Bedingungen
%     der GNU General Public License, wie von der Free Software Foundation,
%     Version 3 der Lizenz oder jeder neueren verffentlichten Version, 
%     weiter verteilen und/oder modifizieren.
% 
%     correlation_gui wird in der Hoffnung, dass es ntzlich sein wird, aber
%     OHNE JEDE GEWHRLEISTUNG, bereitgestellt; sogar ohne die implizite
%     Gewhrleistung der MARKTFHIGKEIT oder EIGNUNG FR EINEN BESTIMMTEN ZWECK.
%     Siehe die GNU General Public License fr weitere Details.
% 
%     Sie sollten eine Kopie der GNU General Public License zusammen mit diesem
%     Programm erhalten haben. Wenn nicht, siehe <https://www.gnu.org/licenses/>.

function saveAvailable(handles)
% saveAll -     Saves data, parameters and up to this point calculated 
%               results to the file specified by handles.filePathSave and
%               handles.fileNameSave
% 
% Syntax:  saveAvailable(handles)
%
% Inputs:
%    handles - handles structure with all data from the main GUI
%
% Outputs:
%

% Other m-files required: none
% Subfunctions: none
% MAT-files required: none
%
% Variables: 	
%
% Known bugs: none
%
% Author: Susanne Pieschner
% Last revision: 22-July-2015

%%

% open/create result file for writing. Discard existing contents, if any
resultFile =  fopen([handles.pathNameSave handles.fileNameSave],'w');

fprintf(resultFile,'%-20s %20s\n','# Calculation date: ', datestr(now));
fprintf(resultFile,'%-c\n','#' );

%% input data
fprintf(resultFile,'%-20s\n','# [Input data]');
fprintf(resultFile,'%-20s\n',['# File = ' handles.fileName]);
fprintf(resultFile,'%-20s %3.0f %7s\n','# Beam stop cut-off:',...
   handles.indexBeamStop, 'data points');
fprintf(resultFile,'%-20s %6.0f\n','# Number of data points used:',...
   handles.numDataUsed);
fprintf(resultFile,'%-c\n','#');


%% Porod fit
if (isfield(handles,'porodFitP'))
    fprintf(resultFile,'%-20s\n','# [PorodFit]');
    fprintf(resultFile,'%-20s %10.8f %c %10.8f\n',...
        '# Porod fitting range, s [1/nm]: ', handles.minScattVectPorod,...
        '-' ,handles.maxScattVectPorod);
    fprintf(resultFile,'%-30s\n',...
        '# Fitting function: I(s) = P*s^(-4) + c1*s^2 + c2');
    fprintf(resultFile,'%-30s\n',...
        '# Fitted parameters:');

    isFixedText = {''; '   fixed'};
    fprintf(resultFile,'%-5s %14.8f %9s\n', '#  Q  = ', handles.Q, 'e.u./nm^6');
    fprintf(resultFile,'%-5s %12.8g %8s\n', '#  P  = ', handles.porodFitP,...
            isFixedText{handles.isFixedP+1});
    fprintf(resultFile,'%-5s %14.8f %8s\n', '#  c1 = ', handles.porodFitC1,...
        isFixedText{handles.isFixedC1+1});
    fprintf(resultFile,'%-5s %14.8f %8s\n', '#  c2 = ', handles.porodFitC2,... 
            isFixedText{handles.isFixedC2+1});
    fprintf(resultFile,'%-5s %12.8g\n', '#  K''''(0) = ',handles.K2Zero);
    fprintf(resultFile,'%-5s %12.8g\n', '#  Error norm: || I - I_fit ||_2 = ',...
            handles.porodFitErrorNorm);
    fprintf(resultFile,'%-c\n','#');

    fprintf(resultFile,'%-20s\n','# [DCT]');
    fprintf(resultFile,'%-20s %10.5f\n',...
        '# Width of Gaussian window function: ', handles.sigma);
    fprintf(resultFile,'%-c\n','#');
end

%% model function fit
if (isfield(handles,'paramModelFcnFit'))
    fprintf(resultFile,'%-20s\n','# [Model function fit]');
    fprintf(resultFile,'%-20s\n','# Parameter inputs:');    

    fprintf(resultFile,'%-13s %13s %12s %12s\n','#', 'starting value', ...
        'lower bound', 'upper bound');
    A = [handles.startValModelFcnFit' handles.lowBoundModelFcnFit'...
        handles.upBoundModelFcnFit'];
    fprintf(resultFile,'%-13s %13f %12f %12f\n','# sigma_a',A(1,:));
    fprintf(resultFile,'%-13s %13f %12f %12f\n','# sigma_c',A(2,:));
    fprintf(resultFile,'%-13s %13f %12f %12f\n','# d_a',A(3,:));
    fprintf(resultFile,'%-13s %13f %12f %12f\n','# d_c',A(4,:));
    fprintf(resultFile,'%-c\n','#');
    fprintf(resultFile,'%-15s %10.8f\n', ['# Step size for higher '...
        'resolution of the model function[1/nm]: '], ...
        handles.stepSizeModelFcnFit);
    fprintf(resultFile,'%-15s %10.8f\n', ['# Resolution width for '...
        'convultion in model function [1/nm]: '], handles.resolWidthModelFcnFit);

    fprintf(resultFile,'%-30s\n',...
        '# Fitted parameters:');
    fprintf(resultFile,'%-5s %14.8f \n', '#  Sigma_a = ',...
        handles.paramModelFcnFit(1));
    fprintf(resultFile,'%-5s %14.8f \n', '#  Sigma_c = ',...
        handles.paramModelFcnFit(2));
    fprintf(resultFile,'%-5s %14.8f \n', '#  d_a     = ',...
        handles.paramModelFcnFit(3));
    fprintf(resultFile,'%-5s %14.8f \n', '#  d_c     = ',...
        handles.paramModelFcnFit(4));
    fprintf(resultFile,'%-5s %14.8g \n', '#  Error norm = ',...
        handles.errorNormModelFcnFit);
    fprintf(resultFile,'%-c\n','#');
    fprintf(resultFile,'%-c\n','#');
end

%% data and results
fprintf(resultFile,'%-20s\n','# [Results]');

%% first table
% possible entries: scatter vectors, absolute intensities, Desmeared errors,
%                   Is2, Porod Fit

formatTextResult1 = '%-3s %15s %15s';
formatValuesResult1 = ' %18.10f %15.3f';
R1headline1 = {'#  ','scatter vectors', 'abs. intensity'};
R1headline2 = {'#  ',' in [1/nm]', ' in [e.u./nm^3]'};
Results1 = [handles.scattVect(handles.indexBeamStop+1:end) ...
       handles.absInt(handles.indexBeamStop+1:end)];

if (~isempty(handles.desmearedError))
    formatTextResult1 = [formatTextResult1 ' %11s'];
    formatValuesResult1 = [formatValuesResult1 ' %11.3f'];
    R1headline1 = {R1headline1{:}, 'Error'};
    R1headline2 = {R1headline2{:}, ' '};
    Results1 = [Results1 handles.desmearedError(handles.indexBeamStop+1:end)];
end

if (isfield(handles,'Is2'))
    formatTextResult1 = [formatTextResult1 ' %15s'];
    formatValuesResult1 = [formatValuesResult1 ' %15.8f'];
    R1headline1 = {R1headline1{:}, 'I(s)*s^2'};
    R1headline2 = {R1headline2{:}, ' in [e.u./nm^5]'};
    Results1 = [Results1 handles.Is2];
end

if (isfield(handles,'porodFit'))
    formatTextResult1 = [formatTextResult1 ' %20s'];
    formatValuesResult1 = [formatValuesResult1 ' %20.8f'];
    R1headline1 = {R1headline1{:}, 'P*s^(-4)+c1*s^2+c2'};
    R1headline2 = {R1headline2{:}, ' in [e.u./nm^3]'};
    Results1 = [Results1 handles.porodFit];
end

formatTextResult1 = [formatTextResult1 ' \n'];
formatValuesResult1 = [formatValuesResult1 ' \n'];
fprintf(resultFile,formatTextResult1, R1headline1{:});
fprintf(resultFile,formatTextResult1, R1headline2{:});
% Note: transpose of results matrix is used to write the file 
fprintf(resultFile,formatValuesResult1, Results1');

%% second table
% possible entries: equidistant scatter vectors, PIs4, model function fit

if( isfield(handles,'PIs4') )
    formatTextResult2 = ' %-3s %15s %25s';
    formatValuesResult2 = ' %18.10f %25.10f';
    R2headline1 = {'#  ','equidistant', '16*pi^3*wf(s)*'};
    R2headline2 = {'#  ','scatter vectors', '(P-(I-c2)*s^4+c1*s^6)'};
    R2headline3 = {'#  ',' in [1/nm]', ' in [e.u./nm^7]'};
    Results2 = [handles.equidistScattVect handles.PIs4];
    
    if( isfield(handles,'PIs4') ) 
        formatTextResult2 = [formatTextResult2 ' %20s'];
        formatValuesResult2 = [formatValuesResult2 ' %20.10f'];
        R2headline1 = { R2headline1{:}, 'model function'};
        R2headline2 = {R2headline2{:}, ' '};
        R2headline3 = {R2headline3{:}, ' in [e.u./nm^7]'};
        Results2 = [Results2 interp1(handles.scattVectHighResol,...
                        handles.modelFcnFit, handles.equidistScattVect)];
    end
    
    formatTextResult2 = [formatTextResult2 ' \n'];
    formatValuesResult2 = [formatValuesResult2 ' \n'];
    fprintf(resultFile,'\n\n' );
    fprintf(resultFile,formatTextResult2, R2headline1{:});
    fprintf(resultFile,formatTextResult2, R2headline2{:});
    fprintf(resultFile,formatTextResult2, R2headline3{:});
    % Note: transpose of results matrix is used to write the file 
    fprintf(resultFile,formatValuesResult2, Results2');
end


%% third table
% possible entries: zvalues, K''(z), transformed model function, K(z)

if( isfield(handles,'zValues') )
    formatTextResult3 = ' %-3s %15s';
    formatValuesResult3 = ' %18.10f';
    R3headline1 = {'#  ','z'};
    R3headline2 = {'#  ',''};
    R3headline3 = {'#  ',' in [nm]'};
    Results3 = handles.zValues;
    
    if( isfield(handles, 'K2') )
        formatTextResult3 = [formatTextResult3 ' %15s'];
        formatValuesResult3 = [formatValuesResult3 ' %15.8f'];
        R3headline1 = {R3headline1{:},'K''''(z)'};
        R3headline2 = {R3headline2{:},''};
        R3headline3 = {R3headline3{:},' in [1/nm^8]'};
        Results3 = [Results3 handles.K2];
    end
    
    if( isfield(handles, 'transformedModelFcn') )
        formatTextResult3 = [formatTextResult3 ' %15s'];
        formatValuesResult3 = [formatValuesResult3 ' %15.8f'];
        R3headline1 = {R3headline1{:},'transformed'};
        R3headline2 = {R3headline2{:},'model function'};
        R3headline3 = {R3headline3{:},' in [1/nm^8]'};
        Results3 = [Results3 interp1(handles.zValTransformedModelFcn,...
                        handles.transformedModelFcn, handles.zValues)];
    end
    
    if( isfield(handles, 'K') )
        formatTextResult3 = [formatTextResult3 ' %15s'];
        formatValuesResult3 = [formatValuesResult3 ' %15.8f'];
        R3headline1 = {R3headline1{:},'K(z)'};
        R3headline2 = {R3headline2{:},' '};
        R3headline3 = {R3headline3{:},' in [1/nm^6]'};
        Results3 = [Results3 handles.K];
    end
    
    formatTextResult3 = [formatTextResult3 '\n'];
    formatValuesResult3 = [formatValuesResult3 '\n'];
    fprintf(resultFile,'\n\n' );
    fprintf(resultFile,formatTextResult3, R3headline1{:});
    fprintf(resultFile,formatTextResult3, R3headline2{:});
    fprintf(resultFile,formatTextResult3, R3headline3{:});
    % Note: transpose of results matrix is used to write the file 
    fprintf(resultFile,formatValuesResult3, Results3');
end

%% close file
fclose(resultFile);