%     This file is part of correlation_gui.
% 
%     correlation_gui is free software: you can redistribute it and/or modify
%     it under the terms of the GNU General Public License as published by
%     the Free Software Foundation, either version 3 of the License, or
%     any later version.
% 
%     correlation_gui is distributed in the hope that it will be useful,
%     but WITHOUT ANY WARRANTY; without even the implied warranty of
%     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%     GNU General Public License for more details.
% 
%     You should have received a copy of the GNU General Public License
%     along with correlation_gui.  If not, see <http://www.gnu.org/licenses/>.
% 
%     Diese Datei ist Teil von correlation_gui.
% 
%     correlation_gui ist Freie Software: Sie knnen es unter den Bedingungen
%     der GNU General Public License, wie von der Free Software Foundation,
%     Version 3 der Lizenz oder jeder neueren verffentlichten Version, 
%     weiter verteilen und/oder modifizieren.
% 
%     correlation_gui wird in der Hoffnung, dass es ntzlich sein wird, aber
%     OHNE JEDE GEWHRLEISTUNG, bereitgestellt; sogar ohne die implizite
%     Gewhrleistung der MARKTFHIGKEIT oder EIGNUNG FR EINEN BESTIMMTEN ZWECK.
%     Siehe die GNU General Public License fr weitere Details.
% 
%     Sie sollten eine Kopie der GNU General Public License zusammen mit diesem
%     Programm erhalten haben. Wenn nicht, siehe <https://www.gnu.org/licenses/>.

function [wfValues] = windowFunction(scatterVector, sigma)
% windowFunction -  computes the values of the window function used in the
%                   DFT; a Gaussian window is used: 
%                   exp(-(2*pi*sigma.*scatterVector)^2)
% 
% Syntax:  [wfValues] = windowFunction(scatterVector, sigma)
%
% Inputs:
%    scatterVector - used values of the scatter vectors in 1/nm 
%    sigma - width of the Gaussian window function
%
% Outputs:
%    wfValues - values of the Gaussian window function at the points of
%               scatterVector

% Other m-files required: none
% Subfunctions: none
% MAT-files required: none

% Known bugs: none
%
% Author: Susanne Pieschner
% Last revision: 21-May-2015

%%
wfValues = exp(-(2*pi*sigma.*scatterVector).^2);

end

